var expect = require('chai').expect;
var weatherdata = require('../../models/weatherdata.js');

describe('weatherdatatest', function() {
  it('canary', function() {
    expect(true).to.be.eql(true);
  });
  
  it('273.15 K is 0C', function() {
    expect(0).to.be.eql(weatherdata.k2c(273.15));
  });

  it('300.15 K is 27C', function() {
    expect(27.00).to.be.eql(weatherdata.k2c(300.15));
  });

  it('264.49 K is -8.66C', function() {
    expect(-8.66).to.be.eql(weatherdata.k2c(264.49));
  });
  
  it('getWeatherData for lat = 39.73 lon = -104.99', function(done) {
    var callback = function(data) {
      expect(0).to.be.below(data.indexOf('temp'));
      expect(0).to.be.below(data.indexOf('Denver'));
      done();
    }
    
    var lat = 39.73;
    var lon = -104.99;
    weatherdata.getWeatherData(lat, lon, callback);
  });
  
  var rawWeatherData = '{"coord":{"lon":-104.98,"lat":39.74},"weather":[{"id":600,"main":"Snow","description":"light snow","icon":"13d"},{"id":701,"main":"Mist","description":"mist","icon":"50d"}],"base":"cmc stations","main":{"temp":264.49,"pressure":1018,"humidity":72,"temp_min":264.15,"temp_max":265.15},"wind":{"speed":2.6,"deg":350},"clouds":{"all":90},"dt":1450375320,"sys":{"type":1,"id":546,"message":0.0047,"country":"US","sunrise":1450361731,"sunset":1450395434},"id":5419384,"name":"Denver","cod":200}';
  
  it('parseWeatherData', function() {
    var result = weatherdata.parseWeatherData(rawWeatherData);
    expect(-8.66).to.be.eql(result.temperature);
    expect('light snow').to.be.eql(result.condition);
  });
  
  it('sendWeatherData sends back JSON', function(done) {
    var res = {
      json: function(result) {
        expect(-8.66).to.be.eql(result.temperature);
        expect('light snow').to.be.eql(result.condition);
        done();
      }
    }
    weatherdata.sendWeatherData(res, rawWeatherData);
  });
  
  it('weather receives query and sends response', function(done) {
    var req = {
      query: {lat: 39, lon: -149}
    };
    
    var res = {};
    
    weatherdatamock = {}
    weatherdatamock.__proto__ = weatherdata;
    
    weatherdatamock.sendWeatherData = function(resReceived, data) {
      expect('sampledata').be.be.eql(data);
      expect(res).to.be.eql(resReceived);
      done();
    }
    
    weatherdatamock.getWeatherData = function(lat, lon, callback) {
      expect(39).to.be.eql(lat);
      expect(-149).to.be.eql(lon);
      callback('sampledata');
    }
    
    weatherdatamock.weather(req, res);
  });
});